==> necroplayer_0.3.0.orig.tar.gz: necroplayer-0.3.0.orig/translations/necroplayer_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="19"/>
        <location filename="../src/SettingsDialog.cpp" line="47"/>
        <source>Playlist</source>
        <translation>Список</translation>
    </message>
    <message>
        <source>Use metadata</source>
        <translation type="obsolete">Использовать метаданные</translation>
    </message>
    <message>
        <source>Use filenames</source>
        <translation type="obsolete">Использовать имена файлов</translation>
    </message>
    <message>
        <source>Update tags when files are added</source>
        <translation type="obsolete">Обновлять теги при добавлении файлов</translation>
    </message>
    <message>
        <source>Update tags when file played</source>
        <translation type="obsolete">Обновлять теги при проигрывании файла</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="27"/>
        <source>Metadata</source>
        <translation>Метаданные</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="29"/>
        <source>Filenames</source>
        <translation>Имена файлов</translation>
    </message>
    <message>
        <source>Auto update</source>
        <translation type="obsolete">Обновлять автоматически</translation>
    </message>
    <message>
        <source>Update on playing</source>
        <translation type="obsolete">Обновлять при проигрывании</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="44"/>
        <source>Retrieve metadata:</source>
        <translation>Извлекать метаданные:</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="49"/>
        <source>Played song</source>
        <translation>Проигрываемое</translation>
    </message>
    <message>
        <source>Save playlist on quit</source>
        <translation type="obsolete">Сохранять список при выходе</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="67"/>
        <source>Save playing position on quit</source>
        <translation>Сохранять позицию при выходе</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="80"/>
        <source>Music Directory</source>
        <translation>Директория с музыкой</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="87"/>
        <source>Directory:</source>
        <translation>Директория:</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="95"/>
        <source>Browse</source>
        <translation>Выбрать</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="102"/>
        <source>Show hidden files</source>
        <translation>Показывать скрытые файлы</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="122"/>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="181"/>
        <source>Select your music directory</source>
        <translation>Выбор директории с музыкой</translation>
    </message>
</context>
<context>
    <name>UI</name>
    <message>
        <location filename="../src/UI.cpp" line="50"/>
        <source>Playlist</source>
        <translation>Список</translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="51"/>
        <source>Files</source>
        <translation>Файлы</translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="208"/>
        <source>Load Playlist</source>
        <translation>Загрузить список</translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="211"/>
        <location filename="../src/UI.cpp" line="288"/>
        <source>Save Playlist</source>
        <translation>Сохранить список</translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="214"/>
        <source>Open Url</source>
        <translation>Открыть адрес</translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="223"/>
        <source>File</source>
        <translation>Файл</translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="263"/>
        <source>Open Playlist</source>
        <translation>Открыть список</translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="264"/>
        <source>Playlist files ( *.m3u *.M3U *.pls *.PLS)</source>
        <translation>Списки ( *.m3u *.M3U *.pls *.PLS)</translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="289"/>
        <source>Playlist files ( *.m3u *.M3U)</source>
        <translation>Списки ( *.m3u *.M3U)</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation type="obsolete">Директория</translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="205"/>
        <location filename="../src/UI.cpp" line="228"/>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
</context>
<context>
    <name>UIControl</name>
    <message>
        <location filename="../src/UIControl.cpp" line="15"/>
        <source>Random</source>
        <translation>Случайно</translation>
    </message>
</context>
<context>
    <name>UIFolder</name>
    <message>
        <location filename="../src/UIFolder.cpp" line="15"/>
        <source>Add</source>
        <translation>Добавить</translation>
    </message>
    <message>
        <location filename="../src/UIFolder.cpp" line="16"/>
        <source>Replace</source>
        <translation>Заменить</translation>
    </message>
</context>
<context>
    <name>UIPlaylist</name>
    <message>
        <source>Remove</source>
        <translation type="obsolete">Удалить</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="obsolete">Очистить</translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="obsolete">Сохранить</translation>
    </message>
</context>
<context>
    <name>UrlDialog</name>
    <message>
        <location filename="../src/UrlDialog.cpp" line="21"/>
        <source>Url</source>
        <translation>Адрес</translation>
    </message>
</context>
</TS>

==> necroplayer_0.3.1.orig.tar.gz: necroplayer-0.3.1.orig/translations/necroplayer_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="19"/>
        <location filename="../src/SettingsDialog.cpp" line="47"/>
        <source>Playlist</source>
        <translation>Список</translation>
    </message>
    <message>
        <source>Use metadata</source>
        <translation type="obsolete">Использовать метаданные</translation>
    </message>
    <message>
        <source>Use filenames</source>
        <translation type="obsolete">Использовать имена файлов</translation>
    </message>
    <message>
        <source>Update tags when files are added</source>
        <translation type="obsolete">Обновлять теги при добавлении файлов</translation>
    </message>
    <message>
        <source>Update tags when file played</source>
        <translation type="obsolete">Обновлять теги при проигрывании файла</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="27"/>
        <source>Metadata</source>
        <translation>Метаданные</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="29"/>
        <source>Filenames</source>
        <translation>Имена файлов</translation>
    </message>
    <message>
        <source>Auto update</source>
        <translation type="obsolete">Обновлять автоматически</translation>
    </message>
    <message>
        <source>Update on playing</source>
        <translation type="obsolete">Обновлять при проигрывании</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="44"/>
        <source>Retrieve metadata:</source>
        <translation>Извлекать метаданные:</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="49"/>
        <source>Played song</source>
        <translation>Проигрываемое</translation>
    </message>
    <message>
        <source>Save playlist on quit</source>
        <translation type="obsolete">Сохранять список при выходе</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="67"/>
        <source>Save playing position on quit</source>
        <translation>Сохранять позицию при выходе</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="80"/>
        <source>Music Directory</source>
        <translation>Директория с музыкой</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="87"/>
        <source>Directory:</source>
        <translation>Директория:</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="95"/>
        <source>Browse</source>
        <translation>Выбрать</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="102"/>
        <source>Show hidden files</source>
        <translation>Показывать скрытые файлы</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="122"/>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../src/SettingsDialog.cpp" line="181"/>
        <source>Select your music directory</source>
        <translation>Выбор директории с музыкой</translation>
    </message>
</context>
<context>
    <name>UI</name>
    <message>
        <location filename="../src/UI.cpp" line="50"/>
        <source>Playlist</source>
        <translation>Список</translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="51"/>
        <source>Files</source>
        <translation>Файлы</translation>
    </message>
    <message>
        <source>Load Playlist</source>
        <translation type="obsolete">Загрузить список</translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="211"/>
        <location filename="../src/UI.cpp" line="288"/>
        <source>Save Playlist</source>
        <translation>Сохранить список</translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="214"/>
        <source>Open Url</source>
        <translation>Открыть адрес</translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="223"/>
        <source>File</source>
        <translation>Файл</translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="208"/>
        <location filename="../src/UI.cpp" line="263"/>
        <source>Open Playlist</source>
        <translation>Открыть список</translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="264"/>
        <source>Playlist files ( *.m3u *.M3U *.pls *.PLS)</source>
        <translation>Списки ( *.m3u *.M3U *.pls *.PLS)</translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="289"/>
        <source>Playlist files ( *.m3u *.M3U)</source>
        <translation>Списки ( *.m3u *.M3U)</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation type="obsolete">Директория</translation>
    </message>
    <message>
        <location filename="../src/UI.cpp" line="205"/>
        <location filename="../src/UI.cpp" line="228"/>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
</context>
<context>
    <name>UIControl</name>
    <message>
        <location filename="../src/UIControl.cpp" line="15"/>
        <source>Random</source>
        <translation>Случайно</translation>
    </message>
</context>
<context>
    <name>UIFolder</name>
    <message>
        <location filename="../src/UIFolder.cpp" line="15"/>
        <source>Add</source>
        <translation>Добавить</translation>
    </message>
    <message>
        <location filename="../src/UIFolder.cpp" line="16"/>
        <source>Replace</source>
        <translation>Заменить</translation>
    </message>
</context>
<context>
    <name>UIPlaylist</name>
    <message>
        <source>Remove</source>
        <translation type="obsolete">Удалить</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="obsolete">Очистить</translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="obsolete">Сохранить</translation>
    </message>
</context>
<context>
    <name>UrlDialog</name>
    <message>
        <location filename="../src/UrlDialog.cpp" line="21"/>
        <source>Url</source>
        <translation>Адрес</translation>
    </message>
</context>
</TS>
